@@ -14,14 +14,15 @@ from runpy import run_path
 from shutil import copy2
 
 # Pluging location is ~\iris_plugins
-PLUGIN_DIR = Path.home() / Path('iris_plugins')
+PLUGIN_DIR = Path.home() / Path("iris_plugins")
 
 # Create the installation directory if it does not exist
 if not PLUGIN_DIR.exists():
     PLUGIN_DIR.mkdir()
 
-for fname in PLUGIN_DIR.rglob('*.py'):
-    globals().update(run_path(PLUGIN_DIR / fname, run_name = 'iris.plugins'))
+for fname in PLUGIN_DIR.rglob("*.py"):
+    globals().update(run_path(PLUGIN_DIR / fname, run_name="iris.plugins"))
+
 
 def install_plugin(path):
     """ 
@@ -37,4 +38,4 @@ def install_plugin(path):
     new_path = PLUGIN_DIR / path.name
     copy2(path, new_path)
 
-    globals().update(run_path(new_path, run_name = 'iris.plugins'))
+    globals().update(run_path(new_path, run_name="iris.plugins"))
