@@ -6,7 +6,8 @@ Raw dataset classes
 from abc import abstractmethod
 from collections import OrderedDict
 from contextlib import AbstractContextManager
-from functools import partial, wraps
+from functools import wraps
+from pathlib import Path
 
 import numpy as np
 
@@ -15,6 +16,7 @@ from skued import ialign
 
 from .meta import ExperimentalParameter, MetaRawDataset
 
+
 def open_raw(path):
     """
     Open a raw data item, guessing the AbstractRawDataset instance that 
@@ -39,15 +41,22 @@ def open_raw(path):
     ------
     RuntimeError : if the data format could not be guessed.
     """
-    for dataformat in AbstractRawDataset.implementations:
+    if isinstance(path, Path):
+        path = str(path)
+
+    # For easier debugging, data formats are checked in deterministic order
+    for dataformat in sorted(AbstractRawDataset.implementations, key=str):
         try:
             return dataformat(path)
         except:
             pass
-    
-    raise RuntimeError('No data format could be guessed for item located at: \n {}'.format(path))
 
-class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
+    raise RuntimeError(
+        "No data format could be guessed for item located at: \n {}".format(path)
+    )
+
+
+class AbstractRawDataset(AbstractContextManager, metaclass=MetaRawDataset):
     """
     Abstract base class for ultrafast electron diffraction data set. 
     AbstractRawDataset allows for enforced metadata types and values, 
@@ -78,21 +87,29 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
     # Using the ExperimentalParameter allows for automatic registering
     # of the parameters as valid.
     # These attributes can be accessed using the usual property access
-    date            = ExperimentalParameter('date',            str,   default = '')
-    energy          = ExperimentalParameter('energy',          float, default = 90)       # keV
-    pump_wavelength = ExperimentalParameter('pump_wavelength', int,   default = 800)      # nanometers
-    fluence         = ExperimentalParameter('fluence',         float, default = 0)        # mj / cm**2
-    time_zero_shift = ExperimentalParameter('time_zero_shift', float, default = 0)        # picoseconds
-    temperature     = ExperimentalParameter('temperature',     float, default = 293)      # Kelvins
-    exposure        = ExperimentalParameter('exposure',        float, default = 1)        # seconds
-    resolution      = ExperimentalParameter('resolution',      tuple, default = (2048, 2048))
-    time_points     = ExperimentalParameter('time_points',     tuple, default = tuple())  # picoseconds
-    scans           = ExperimentalParameter('scans',           tuple, default = (1,))
-    camera_length   = ExperimentalParameter('camera_length',   float, default = 0.23)     # meters
-    pixel_width     = ExperimentalParameter('pixel_width',     float, default = 14e-6)    # meters
-    notes           = ExperimentalParameter('notes',           str,   default = '')
+    date = ExperimentalParameter("date", str, default="")
+    energy = ExperimentalParameter("energy", float, default=90)  # keV
+    pump_wavelength = ExperimentalParameter(
+        "pump_wavelength", int, default=800
+    )  # nanometers
+    fluence = ExperimentalParameter("fluence", float, default=0)  # mj / cm**2
+    time_zero_shift = ExperimentalParameter(
+        "time_zero_shift", float, default=0
+    )  # picoseconds
+    temperature = ExperimentalParameter("temperature", float, default=293)  # Kelvins
+    exposure = ExperimentalParameter("exposure", float, default=1)  # seconds
+    resolution = ExperimentalParameter("resolution", tuple, default=(2048, 2048))
+    time_points = ExperimentalParameter(
+        "time_points", tuple, default=tuple()
+    )  # picoseconds
+    scans = ExperimentalParameter("scans", tuple, default=(1,))
+    camera_length = ExperimentalParameter(
+        "camera_length", float, default=0.23
+    )  # meters
+    pixel_width = ExperimentalParameter("pixel_width", float, default=14e-6)  # meters
+    notes = ExperimentalParameter("notes", str, default="")
 
-    def __init__(self, source = None, metadata = None):
+    def __init__(self, source=None, metadata=None):
         """
         Parameters
         ----------
@@ -110,17 +127,17 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
         self.source = source
         if metadata:
             self.update_metadata(metadata)
-    
+
     def __exit__(self, *exc):
         pass
-    
+
     def __repr__(self):
-        rep = '< {} object with following metadata: '.format(type(self).__name__)
+        rep = "< {} object with following metadata: ".format(type(self).__name__)
         for key, val in self.metadata.items():
-            rep += '\n    {key}: {val}'.format(key = key, val = val)
-        
-        return rep + ' >'
-    
+            rep += "\n    {key}: {val}".format(key=key, val=val)
+
+        return rep + " >"
+
     def update_metadata(self, metadata):
         """
         Update metadata from a dictionary. Only appropriate keys are used; irrelevant keys are ignored.
@@ -137,9 +154,9 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
     @property
     def metadata(self):
         """ Experimental parameters and dataset metadata as a dictionary. """
-        meta = {k:getattr(self, k) for k in self.valid_metadata} 
+        meta = {k: getattr(self, k) for k in self.valid_metadata}
         # Ordered dictionary by keys is easiest to inspect
-        return OrderedDict( sorted(meta.items(), key = lambda t: t[0]) )
+        return OrderedDict(sorted(meta.items(), key=lambda t: t[0]))
 
     def iterscan(self, scan, **kwargs):
         """
@@ -162,12 +179,12 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
         itertime : generator of diffraction patterns for a single time-delay, in scan order
         """
         if scan not in set(self.scans):
-            raise ValueError('There is no scan {} in available scans'.format(scan))
-        
+            raise ValueError("There is no scan {} in available scans".format(scan))
+
         for timedelay in self.time_points:
-            yield self.raw_data(timedelay = timedelay, scan = scan, **kwargs)
-    
-    def itertime(self, timedelay, exclude_scans = None, **kwargs):
+            yield self.raw_data(timedelay=timedelay, scan=scan, **kwargs)
+
+    def itertime(self, timedelay, exclude_scans=None, **kwargs):
         """
         Generator function of diffraction patterns of the same time-delay, in 
         scan order.
@@ -193,14 +210,14 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
             exclude_scans = set([])
 
         if timedelay not in set(self.time_points):
-            raise ValueError('There is no scan {} in available scans'.format(scan))
-        
+            raise ValueError("There is no scan {} in available scans".format(scan))
+
         valid_scans = sorted(set(self.scans) - set(exclude_scans))
         for scan in valid_scans:
-            yield self.raw_data(timedelay = timedelay, scan = scan, **kwargs)
-    
+            yield self.raw_data(timedelay=timedelay, scan=scan, **kwargs)
+
     @abstractmethod
-    def raw_data(self, timedelay, scan = 1, bgr = True, **kwargs):
+    def raw_data(self, timedelay, scan=1, **kwargs):
         """
         Returns an array of the image at a timedelay and scan.
         
@@ -210,8 +227,8 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
             Acquisition time-delay.
         scan : int, optional
             Scan number. Default is 1.
-        bgr : bool, optional
-            If True (default), laser background is removed before being returned.
+        kwargs
+            Keyword-arguments are ignored.
         
         Returns
         -------
@@ -221,10 +238,18 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
         ------
         ValueError : if ``timedelay`` or ``scan`` are invalid / out of bounds.
         IOError : Filename is not associated with an image/does not exist.
-        """ 
+        """
         pass
-    
-    def reduced(self, exclude_scans = None, align = True, normalize = True, mask = None, processes = 1, dtype = np.float):
+
+    def reduced(
+        self,
+        exclude_scans=None,
+        align=True,
+        normalize=True,
+        mask=None,
+        processes=1,
+        dtype=np.float,
+    ):
         """
         Generator of reduced dataset. The reduced diffraction patterns are generated in order of time-delay.
 
@@ -252,47 +277,58 @@ class AbstractRawDataset(AbstractContextManager, metaclass = MetaRawDataset):
         ------
         pattern : `~numpy.ndarray`, ndim 2
         """
-        kwargs = {'raw'          : self,
-                  'exclude_scans': exclude_scans,
-                  'align'        : align,
-                  'normalize'    : normalize,
-                  'invalid_mask' : mask,
-                  'dtype'        : dtype}
+        kwargs = {
+            "raw": self,
+            "exclude_scans": exclude_scans,
+            "align": align,
+            "normalize": normalize,
+            "invalid_mask": mask,
+            "dtype": dtype,
+        }
+
+        combined = pmap(
+            _raw_combine,
+            self.time_points,
+            kwargs=kwargs,
+            processes=processes,
+            ntotal=len(self.time_points),
+        )
 
-        combined = pmap(_raw_combine, self.time_points, kwargs = kwargs,
-                        processes = processes, ntotal = len(self.time_points))
-        
         # Each image at the same time-delay are aligned to each other. This means that
         # the reference image is different for each time-delay. We align the reduced images
         # to each other as well.
+        # Note : the fast = False fixes issue #11, where single crystal images were not successfully aligned.
         if align:
-            yield from ialign(combined, mask = mask)
+            yield from ialign(combined, mask=mask, fast=False)
         else:
             yield from combined
 
-# For multiprocessing, the function to be mapped must be 
+
+# For multiprocessing, the function to be mapped must be
 # global, hence defined outside of the class method
 def _raw_combine(timedelay, raw, exclude_scans, normalize, align, invalid_mask, dtype):
 
-    images = raw.itertime(timedelay, exclude_scans = exclude_scans)
+    images = raw.itertime(timedelay, exclude_scans=exclude_scans)
 
     if align:
-        images = ialign(images, mask = invalid_mask)
-    
+        # Note : the fast = False fixes issue #11, where single crystal images were not successfully aligned.
+        images = ialign(images, mask=invalid_mask, fast=False)
+
     # Set up normalization
     if normalize:
         valid = np.logical_not(invalid_mask)
-        images, images2 = itercopy(images, copies = 2)
+        images, images2 = itercopy(images, copies=2)
 
         # Compute the total intensity of first image
         # This will be the reference point
         first2, images2 = peek(images2)
         initial_weight = np.sum(first2[valid])
-        weights = (initial_weight/np.sum(image[valid]) for image in images2)
+        weights = (initial_weight / np.sum(image[valid]) for image in images2)
     else:
         weights = None
 
-    return average(images, weights = weights).astype(dtype)
+    return average(images, weights=weights).astype(dtype)
+
 
 def check_raw_bounds(method):
     """
@@ -314,8 +350,12 @@ def check_raw_bounds(method):
         valid_timedelay = timedelay in self.time_points
 
         if (not valid_scan) or (not valid_timedelay):
-            raise ValueError('Requested time-delay {t} and scan {s} are invalid or out-of-bounds'.format(t = timedelay, s = scan))
-        
+            raise ValueError(
+                "Requested time-delay {t} and scan {s} are invalid or out-of-bounds".format(
+                    t=timedelay, s=scan
+                )
+            )
+
         return method(self, timedelay, scan, *args, **kwargs)
-    
+
     return checked_method
